# CHANGELOG

<!-- version list -->

## v1.2.0 (2025-07-13)

### Bug Fixes

- Add python-semantic-release to dev dependencies
  ([`4b7f261`](https://github.com/alejandrogarcia-hub/iam-mcp-server/commit/4b7f26179b7035e3e5f3c5bed0e6db61900e6721))

### Chores

- Update uv.lock with python-semantic-release dependency
  ([`f009435`](https://github.com/alejandrogarcia-hub/iam-mcp-server/commit/f0094350d32ca5e47b0f39c2114e9734a4d480c7))

### Features

- Add automated PyPI release workflow with semantic versioning
  ([`998b6fc`](https://github.com/alejandrogarcia-hub/iam-mcp-server/commit/998b6fca28031f985832bd9e727030a3b990f57c))

- Improve git tag synchronization in release workflow
  ([`0994951`](https://github.com/alejandrogarcia-hub/iam-mcp-server/commit/0994951fa50d8ff522b79de12f51b044fa0b647b))


## v1.1.4 (2025-07-13)

- Initial Release
